@@ -1603,3 +1603,24 @@ class RequestAjaxTests(TestCase):
         resp = self._send_post_request(HTTP_ACCEPT="application/json")
         self.assertEqual(200, resp.status_code)
         self.assertEqual(settings.LOGIN_REDIRECT_URL, resp.json()["location"])
+
+
+@override_settings(
+    CACHES={
+        "default": {
+            "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+        },
+    },
+    ACCOUNT_RATE_LIMITS={"reset_password_email": "1/m"},
+)
+class RateLimitTests(TestCase):
+    def test_case_insensitive_password_reset(self):
+        get_user_model().objects.create(email="a@b.com")
+        resp = self.client.post(
+            reverse("account_reset_password"), data={"email": "a@b.com"}
+        )
+        assert resp.status_code == 302
+        resp = self.client.post(
+            reverse("account_reset_password"), data={"email": "A@B.COM"}
+        )
+        assert resp.status_code == 429
