@@ -90,7 +90,7 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
             }""",
         )
         with patch(
-            "allauth.socialaccount.providers.google.views" ".requests"
+            "allauth.socialaccount.providers.google.views.requests"
         ) as patched_requests:
             patched_requests.get.return_value = response_with_401
             with self.assertRaises(HTTPError):
