@@ -11,18 +11,18 @@ from .provider import InstagramProvider
 
 class InstagramOAuth2Adapter(OAuth2Adapter):
     provider_id = InstagramProvider.id
-    access_token_url = 'https://api.instagram.com/oauth/access_token'
-    authorize_url = 'https://api.instagram.com/oauth/authorize'
-    profile_url = 'https://graph.instagram.com/me'
+    access_token_url = "https://api.instagram.com/oauth/access_token"
+    authorize_url = "https://api.instagram.com/oauth/authorize"
+    profile_url = "https://graph.instagram.com/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        resp = requests.get(self.profile_url,
-                            params={'access_token': token.token,
-                                    'fields': ['id', 'username']})
+        resp = requests.get(
+            self.profile_url,
+            params={"access_token": token.token, "fields": ["id", "username"]},
+        )
         resp.raise_for_status()
         extra_data = resp.json()
-        return self.get_provider().sociallogin_from_response(request,
-                                                             extra_data)
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth2_login = OAuth2LoginView.adapter_view(InstagramOAuth2Adapter)
